@@ -46,7 +46,7 @@ class ShareAPITest(test.TestCase):
     """Share API Test."""
 
     def setUp(self):
-        super(self.__class__, self).setUp()
+        super(ShareAPITest, self).setUp()
         self.controller = shares.ShareController()
         self.mock_object(db, 'availability_zone_get')
         self.mock_object(share_api.API, 'get_all',
@@ -787,7 +787,7 @@ def _fake_access_get(self, ctxt, access_id):
 class ShareActionsTest(test.TestCase):
 
     def setUp(self):
-        super(self.__class__, self).setUp()
+        super(ShareActionsTest, self).setUp()
         self.controller = shares.ShareController()
         self.mock_object(share_api.API, 'get', stubs.stub_share_get)
         self.mock_policy_check = self.mock_object(policy, 'check_policy')
@@ -796,8 +796,10 @@ class ShareActionsTest(test.TestCase):
         {'access_type': 'ip', 'access_to': '127.0.0.1'},
         {'access_type': 'user', 'access_to': '1' * 4},
         {'access_type': 'user', 'access_to': '1' * 255},
-        {'access_type': 'user', 'access_to': 'fake\\]{.-_\'`;}['},
-        {'access_type': 'user', 'access_to': 'MYDOMAIN\\Administrator'},
+        {'access_type': 'user', 'access_to': 'fake{.-_\'`}'},
+        {'access_type': 'user', 'access_to': 'MYDOMAIN-Administrator'},
+        {'access_type': 'user', 'access_to': 'test group name'},
+        {'access_type': 'user', 'access_to': 'group$.-_\'`{}'},
         {'access_type': 'cert', 'access_to': 'x'},
         {'access_type': 'cert', 'access_to': 'tenant.example.com'},
         {'access_type': 'cert', 'access_to': 'x' * 64},
@@ -830,7 +832,9 @@ class ShareActionsTest(test.TestCase):
         {'access_type': 'user', 'access_to': '1'},
         {'access_type': 'user', 'access_to': '1' * 3},
         {'access_type': 'user', 'access_to': '1' * 256},
-        {'access_type': 'user', 'access_to': 'root^'},
+        {'access_type': 'user', 'access_to': 'root<>'},
+        {'access_type': 'user', 'access_to': 'group\\'},
+        {'access_type': 'user', 'access_to': '+=*?group'},
         {'access_type': 'cert', 'access_to': ''},
         {'access_type': 'cert', 'access_to': ' '},
         {'access_type': 'cert', 'access_to': 'x' * 65},
@@ -1005,7 +1009,7 @@ class ShareActionsTest(test.TestCase):
 class ShareAdminActionsAPITest(test.TestCase):
 
     def setUp(self):
-        super(self.__class__, self).setUp()
+        super(ShareAdminActionsAPITest, self).setUp()
         CONF.set_default("default_share_type", None)
         self.flags(rpc_backend='manila.openstack.common.rpc.impl_fake')
         self.share_api = share_api.API()
